<?php
/**
 * @package bgbn
 */

bgbn_load_section_header();

global $bgbn_section_data, $bgbn_is_js_template;
$section_name     = bgbn_get_section_name( $bgbn_section_data, $bgbn_is_js_template );
$columns          = ( isset( $bgbn_section_data['data']['columns'] ) ) ? $bgbn_section_data['data']['columns'] : 3;
$caption_color    = ( isset( $bgbn_section_data['data']['caption-color'] ) ) ? $bgbn_section_data['data']['caption-color'] : 'light';
$captions         = ( isset( $bgbn_section_data['data']['captions'] ) ) ? $bgbn_section_data['data']['captions'] : 'reveal';
$aspect           = ( isset( $bgbn_section_data['data']['aspect'] ) ) ? $bgbn_section_data['data']['aspect'] : 'square';
$title            = ( isset( $bgbn_section_data['data']['title'] ) ) ? $bgbn_section_data['data']['title'] : '';
$background_image = ( isset( $bgbn_section_data['data']['background-image'] ) ) ? $bgbn_section_data['data']['background-image'] : 0;
$background_color = ( isset( $bgbn_section_data['data']['background-color'] ) ) ? $bgbn_section_data['data']['background-color'] : '';
$background_style = ( isset( $bgbn_section_data['data']['background-style'] ) ) ? $bgbn_section_data['data']['background-style'] : 'tile';
$darken           = ( isset( $bgbn_section_data['data']['darken'] ) ) ? $bgbn_section_data['data']['darken'] : 0;
$section_order    = ( ! empty( $bgbn_section_data['data']['gallery-item-order'] ) ) ? $bgbn_section_data['data']['gallery-item-order'] : array();
?>

<div class="bgbn-captions-select-wrapper">
	<label for="<?php echo $section_name; ?>[caption-color]"><?php _e( 'Caption color:', 'bgbn' ); ?></label>
	<select id="<?php echo $section_name; ?>[caption-color]" name="<?php echo $section_name; ?>[caption-color]">
		<option value="light"<?php selected( 'light', $caption_color ); ?>><?php echo esc_html( __( 'Light', 'bgbn' ) ); ?></option>
		<option value="dark"<?php selected( 'dark', $caption_color ); ?>><?php echo esc_html( __( 'Dark', 'bgbn' ) ); ?></option>
	</select>
</div>

<div class="bgbn-captions-select-wrapper">
	<label for="<?php echo $section_name; ?>[captions]"><?php _e( 'Caption style:', 'bgbn' ); ?></label>
	<select id="<?php echo $section_name; ?>[captions]" name="<?php echo $section_name; ?>[captions]">
		<option value="overlay"<?php selected( 'overlay', $captions ); ?>><?php echo esc_html( __( 'Overlay', 'bgbn' ) ); ?></option>
		<option value="reveal"<?php selected( 'reveal', $captions ); ?>><?php echo esc_html( __( 'Reveal', 'bgbn' ) ); ?></option>
		<option value="none"<?php selected( 'none', $captions ); ?>><?php echo esc_html( __( 'None', 'bgbn' ) ); ?></option>
	</select>
</div>

<div class="bgbn-aspect-select-wrapper">
	<label for="<?php echo $section_name; ?>[aspect]"><?php _e( 'Aspect ratio:', 'bgbn' ); ?></label>
	<select id="<?php echo $section_name; ?>[aspect]" name="<?php echo $section_name; ?>[aspect]">
		<option value="landscape"<?php selected( 'landscape', $aspect ); ?>><?php echo esc_html( __( 'Landscape', 'bgbn' ) ); ?></option>
		<option value="portrait"<?php selected( 'portrait', $aspect ); ?>><?php echo esc_html( __( 'Portrait', 'bgbn' ) ); ?></option>
		<option value="square"<?php selected( 'square', $aspect ); ?>><?php echo esc_html( __( 'Square', 'bgbn' ) ); ?></option>
		<option value="none"<?php selected( 'none', $aspect ); ?>><?php echo esc_html( __( 'None', 'bgbn' ) ); ?></option>
	</select>
</div>

<div class="bgbn-columns-select-wrapper">
	<label for="<?php echo $section_name; ?>[columns]"><?php _e( 'Columns:', 'bgbn' ); ?></label>
	<select id="<?php echo $section_name; ?>[columns]" name="<?php echo $section_name; ?>[columns]" class="bgbn-gallery-columns">
		<option value="1"<?php selected( 1, $columns ); ?>>1</option>
		<option value="2"<?php selected( 2, $columns ); ?>>2</option>
		<option value="3"<?php selected( 3, $columns ); ?>>3</option>
		<option value="4"<?php selected( 4, $columns ); ?>>4</option>
	</select>
</div>

<div class="bgbn-add-gallery-item-wrapper">
	<a href="#" class="button button-primary bgbn-button-large button-large bgbn-gallery-add-item"><?php _e( 'Add New Item', 'bgbn' ); ?></a>
</div>

<div class="bgbn-gallery-items">
	<div class="bgbn-gallery-items-stage bgbn-gallery-columns-<?php echo absint( $columns ); ?>">
		<?php foreach ( $section_order as $key => $section_id  ) : ?>
			<?php if ( isset( $bgbn_section_data['data']['gallery-items'][ $section_id ] ) ) : ?>
				<?php global $bgbn_gallery_id; $bgbn_gallery_id = $section_id; ?>
				<?php get_template_part( '/inc/builder/sections/builder-templates/gallery', 'item' ); ?>
			<?php endif; ?>
		<?php endforeach; ?>
	</div>
	<input type="hidden" value="<?php echo esc_attr( implode( ',', $section_order ) ); ?>" name="<?php echo $section_name; ?>[gallery-item-order]" class="bgbn-gallery-item-order" />
</div>

<div class="bgbn-gallery-background-options-container">
	<h2 class="bgbn-large-title bgbn-gallery-options-heading">
		<?php _e( 'Options', 'bgbn' ); ?>
	</h2>

	<div class="bgbn-titlediv">
		<div class="bgbn-titlewrap">
			<input placeholder="<?php esc_attr_e( 'Enter title here', 'bgbn' ); ?>" type="text" name="<?php echo $section_name; ?>[title]" class="bgbn-title bgbn-section-header-title-input" value="<?php echo esc_attr( htmlspecialchars( $title ) ); ?>" autocomplete="off" />
		</div>
	</div>

	<div class="bgbn-gallery-background-image-wrapper">
		<?php
			bgbn_get_builder_base()->add_uploader(
				$section_name . '[background-image]',
				bgbn_sanitize_image_id( $background_image ),
				array(
					'add'    => __( 'Set background image', 'bgbn' ),
					'remove' => __( 'Remove background image', 'bgbn' ),
					'title'  => __( 'Background image', 'bgbn' ),
					'button' => __( 'Use as Background Image', 'bgbn' ),
				)
			);
		?>
	</div>

	<div class="bgbn-gallery-background-options-wrapper">
		<h4><?php _e( 'Background image', 'bgbn' ); ?></h4>
		<input id="<?php echo $section_name; ?>[darken]" type="checkbox" name="<?php echo $section_name; ?>[darken]" value="1"<?php checked( $darken ); ?> />
		<label for="<?php echo $section_name; ?>[darken]">
			<?php _e( 'Darken to improve readability', 'bgbn' ); ?>
		</label>

		<h4><?php _e( 'Background color', 'bgbn' ); ?></h4>
		<input id="<?php echo $section_name; ?>[background-color]" type="text" name="<?php echo $section_name . '[background-color]'; ?>" class="bgbn-gallery-background-color" value="<?php echo maybe_hash_hex_color( $background_color ); ?>" />

		<h4><?php _e( 'Background style:', 'bgbn' ); ?></h4>
		<select id="<?php echo $section_name; ?>[background-style]" name="<?php echo $section_name; ?>[background-style]">
			<option value="tile"<?php selected( 'tile', $background_style ); ?>><?php echo esc_html( __( 'Tile', 'bgbn' ) ); ?></option>
			<option value="cover"<?php selected( 'cover', $background_style ); ?>><?php echo esc_html( __( 'Cover', 'bgbn' ) ); ?></option>
		</select>
	</div>
</div>

<input type="hidden" class="bgbn-section-state" name="<?php echo $section_name; ?>[state]" value="<?php if ( isset( $bgbn_section_data['data']['state'] ) ) echo esc_attr( $bgbn_section_data['data']['state'] ); else echo 'open'; ?>" />
<?php bgbn_load_section_footer();