<?php
/**
 * @package bgbn
 */

bgbn_load_section_header();

global $bgbn_section_data, $bgbn_is_js_template;
$section_name   = bgbn_get_section_name( $bgbn_section_data, $bgbn_is_js_template );
$columns_number = ( isset( $bgbn_section_data['data']['columns-number'] ) ) ? $bgbn_section_data['data']['columns-number'] : 3;
$section_order  = ( ! empty( $bgbn_section_data['data']['columns-order'] ) ) ? $bgbn_section_data['data']['columns-order'] : range(1, 4);
$columns_class  = ( in_array( $columns_number, range( 1, 4 ) ) && true !== $bgbn_is_js_template ) ? $columns_number : 3;
?>

<?php if ( false === bgbn_is_plus() ) : ?>
<div class="bgbn-plus-info">
	<p>
		<em>
		<?php
		printf(
			__( '%s and convert any column into an area for widgets.', 'bgbn' ),
			sprintf(
				'<a href="%1$s" target="_blank">%2$s</a>',
				esc_url( bgbn_get_plus_link( 'widget-area' ) ),
				sprintf(
					__( 'Upgrade to %s', 'bgbn' ),
					'bgbn Plus'
				)
			)
		);
		?>
		</em>
	</p>
</div>
<?php endif; ?>

<div class="bgbn-columns-select bgbn-select">
	<label for="<?php echo $section_name; ?>[columns-number]"><?php _e( 'Columns:', 'bgbn' ); ?></label>
	<select id="<?php echo $section_name; ?>[columns-number]" class="bgbn-text-columns" name="<?php echo $section_name; ?>[columns-number]">
		<option value="1"<?php selected( 1, $columns_number ); ?>>1</option>
		<option value="2"<?php selected( 2, $columns_number ); ?>>2</option>
		<option value="3"<?php selected( 3, $columns_number ); ?>>3</option>
		<option value="4"<?php selected( 4, $columns_number ); ?>>4</option>
	</select>
</div>

<div class="bgbn-titlediv">
	<div class="bgbn-titlewrap">
		<input placeholder="<?php esc_attr_e( 'Enter title here' ); ?>" type="text" name="<?php echo $section_name; ?>[title]" class="bgbn-title bgbn-section-header-title-input" value="<?php if ( isset( $bgbn_section_data['data']['title'] ) ) echo esc_attr( htmlspecialchars( $bgbn_section_data['data']['title'] ) ); ?>" autocomplete="off" />
	</div>
</div>

<div class="bgbn-text-columns-stage bgbn-text-columns-<?php echo $columns_class; ?>">
	<?php $j = 1; foreach ( $section_order as $key => $i ) : ?>
	<?php
		$column_name = $section_name . '[columns][' . $i . ']';
		$link     = ( isset( $bgbn_section_data['data']['columns'][ $i ]['image-link'] ) ) ? $bgbn_section_data['data']['columns'][ $i ]['image-link'] : '';
		$image_id = ( isset( $bgbn_section_data['data']['columns'][ $i ]['image-id'] ) ) ? $bgbn_section_data['data']['columns'][ $i ]['image-id'] : 0;
		$title    = ( isset( $bgbn_section_data['data']['columns'][ $i ]['title'] ) ) ? $bgbn_section_data['data']['columns'][ $i ]['title'] : '';
		$content  = ( isset( $bgbn_section_data['data']['columns'][ $i ]['content'] ) ) ? $bgbn_section_data['data']['columns'][ $i ]['content'] : '';
	?>
	<div class="bgbn-text-column bgbn-text-column-position-<?php echo $j; ?>" data-id="<?php echo $i; ?>">
		<div title="<?php esc_attr_e( 'Drag-and-drop this column into place', 'bgbn' ); ?>" class="bgbn-sortable-handle">
			<div class="sortable-background"></div>
		</div>

		<?php do_action( 'bgbn_section_text_before_column', $bgbn_section_data, $i ); ?>

		<div class="bgbn-titlediv">
			<input placeholder="<?php esc_attr_e( 'Enter link here', 'bgbn' ); ?>" type="text" name="<?php echo $column_name; ?>[image-link]" class="bgbn-link code widefat" value="<?php echo esc_url( $link ); ?>" autocomplete="off" />
		</div>

		<?php bgbn_get_builder_base()->add_uploader( $column_name, bgbn_sanitize_image_id( $image_id ) ); ?>

		<div class="bgbn-titlediv">
			<div class="bgbn-titlewrap">
				<input placeholder="<?php esc_attr_e( 'Enter title here', 'bgbn' ); ?>" type="text" name="<?php echo $column_name; ?>[title]" class="bgbn-title bgbn-section-header-title-input" value="<?php echo esc_attr( htmlspecialchars( $title ) ); ?>" autocomplete="off" />
			</div>
		</div>

		<?php
		$editor_settings = array(
			'tinymce'       => array(
				'toolbar1' => 'bold,italic,link,bgbn_mce_button_button',
				'toolbar2' => '',
				'toolbar3' => '',
				'toolbar4' => '',
			),
			'quicktags'     => array(
				'buttons' => 'strong,em,link',
			),
			'textarea_name' => $column_name . '[content]'
		);

		if ( true === $bgbn_is_js_template ) : ?>
			<?php bgbn_get_builder_base()->wp_editor( '', 'bgbneditortextcolumn' . $i . 'temp', $editor_settings ); ?>
		<?php else : ?>
			<?php bgbn_get_builder_base()->wp_editor( $content, 'bgbneditortext' . $bgbn_section_data['data']['id'] . $i, $editor_settings ); ?>
		<?php endif; ?>

		<?php do_action( 'bgbn_section_text_after_column', $bgbn_section_data, $i ); ?>
	</div>
	<?php $j++; endforeach; ?>
</div>

<div class="clear"></div>

<input type="hidden" value="<?php echo esc_attr( implode( ',', $section_order ) ); ?>" name="<?php echo $section_name; ?>[columns-order]" class="bgbn-text-columns-order" />
<input type="hidden" class="bgbn-section-state" name="<?php echo $section_name; ?>[state]" value="<?php if ( isset( $bgbn_section_data['data']['state'] ) ) echo esc_attr( $bgbn_section_data['data']['state'] ); else echo 'open'; ?>" />
<?php bgbn_load_section_footer();