<?php
/**
 * @package bgbn
 */

if ( ! function_exists( 'bgbn_customizer_layout_blog' ) ) :
/**
 * Configure settings and controls for the Layout: Blog (Posts Page) section.
 *
 * @since  1.0.0.
 *
 * @param  object    $wp_customize    The global customizer object.
 * @param  string    $section         The section name.
 * @return void
 */
function bgbn_customizer_layout_blog( $wp_customize, $section ) {
	$priority       = new bgbn_Prioritizer();
	$control_prefix = 'bgbn_';
	$setting_prefix = str_replace( $control_prefix, '', $section );

	// Header, Footer, Sidebars heading
	$setting_id = $setting_prefix . '-heading-sidebars';
	$wp_customize->add_control(
		new bgbn_Customize_Misc_Control(
			$wp_customize,
			$control_prefix . $setting_id,
			array(
				'section'  => $section,
				'type'     => 'heading',
				'label'    => __( 'Header, Footer, Sidebars', 'bgbn' ),
				'priority' => $priority->add()
			)
		)
	);

	// Hide site header
	$setting_id = $setting_prefix . '-hide-header';
	$wp_customize->add_setting(
		$setting_id,
		array(
			'default'           => bgbn_get_default( $setting_id ),
			'type'              => 'theme_mod',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		$control_prefix . $setting_id,
		array(
			'settings' => $setting_id,
			'section'  => $section,
			'label'    => __( 'Hide site header', 'bgbn' ),
			'type'     => 'checkbox',
			'priority' => $priority->add()
		)
	);

	// Hide site footer
	$setting_id = $setting_prefix . '-hide-footer';
	$wp_customize->add_setting(
		$setting_id,
		array(
			'default'           => bgbn_get_default( $setting_id ),
			'type'              => 'theme_mod',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		$control_prefix . $setting_id,
		array(
			'settings' => $setting_id,
			'section'  => $section,
			'label'    => __( 'Hide site footer', 'bgbn' ),
			'type'     => 'checkbox',
			'priority' => $priority->add()
		)
	);

	// Left sidebar
	$setting_id = $setting_prefix . '-sidebar-left';
	$wp_customize->add_setting(
		$setting_id,
		array(
			'default'           => bgbn_get_default( $setting_id ),
			'type'              => 'theme_mod',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		$control_prefix . $setting_id,
		array(
			'settings' => $setting_id,
			'section'  => $section,
			'label'    => __( 'Show left sidebar', 'bgbn' ),
			'type'     => 'checkbox',
			'priority' => $priority->add()
		)
	);

	// Right sidebar
	$setting_id = $setting_prefix . '-sidebar-right';
	$wp_customize->add_setting(
		$setting_id,
		array(
			'default'           => bgbn_get_default( $setting_id ),
			'type'              => 'theme_mod',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		$control_prefix . $setting_id,
		array(
			'settings' => $setting_id,
			'section'  => $section,
			'label'    => __( 'Show right sidebar', 'bgbn' ),
			'type'     => 'checkbox',
			'priority' => $priority->add()
		)
	);

	// Featured images
	$setting_id = $setting_prefix . '-featured-images';
	$wp_customize->add_setting(
		$setting_id,
		array(
			'default'           => bgbn_get_default( $setting_id ),
			'type'              => 'theme_mod',
			'sanitize_callback' => 'bgbn_sanitize_choice',
		)
	);
	$wp_customize->add_control(
		$control_prefix . $setting_id,
		array(
			'settings' => $setting_id,
			'section'  => $section,
			'label'    => __( 'Featured Images', 'bgbn' ),
			'type'     => 'select',
			'choices'  => bgbn_get_choices( $setting_id ),
			'priority' => $priority->add()
		)
	);

	// Post date
	$setting_id = $setting_prefix . '-post-date';
	$wp_customize->add_setting(
		$setting_id,
		array(
			'default'           => bgbn_get_default( $setting_id ),
			'type'              => 'theme_mod',
			'sanitize_callback' => 'bgbn_sanitize_choice',
		)
	);
	$wp_customize->add_control(
		$control_prefix . $setting_id,
		array(
			'settings' => $setting_id,
			'section'  => $section,
			'label'    => __( 'Post Date', 'bgbn' ),
			'type'     => 'select',
			'choices'  => bgbn_get_choices( $setting_id ),
			'priority' => $priority->add()
		)
	);

	// Post author
	$setting_id = $setting_prefix . '-post-author';
	$wp_customize->add_setting(
		$setting_id,
		array(
			'default'           => bgbn_get_default( $setting_id ),
			'type'              => 'theme_mod',
			'sanitize_callback' => 'bgbn_sanitize_choice',
		)
	);
	$wp_customize->add_control(
		$control_prefix . $setting_id,
		array(
			'settings' => $setting_id,
			'section'  => $section,
			'label'    => __( 'Post Author', 'bgbn' ),
			'type'     => 'select',
			'choices'  => bgbn_get_choices( $setting_id ),
			'priority' => $priority->add()
		)
	);

	// Content heading
	$setting_id = $setting_prefix . '-heading-content';
	$wp_customize->add_control(
		new bgbn_Customize_Misc_Control(
			$wp_customize,
			$control_prefix . $setting_id,
			array(
				'section'     => $section,
				'type'        => 'heading',
				'label' => __( 'Content', 'bgbn' ),
				'priority'    => $priority->add()
			)
		)
	);

	// Auto excerpt
	$setting_id = $setting_prefix . '-auto-excerpt';
	$wp_customize->add_setting(
		$setting_id,
		array(
			'default'           => bgbn_get_default( $setting_id ),
			'type'              => 'theme_mod',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		$control_prefix . $setting_id,
		array(
			'settings' => $setting_id,
			'section'  => $section,
			'label'    => __( 'Generate excerpts automatically', 'bgbn' ),
			'type'     => 'checkbox',
			'priority' => $priority->add()
		)
	);

	// Post meta heading
	$setting_id = $setting_prefix . '-heading-postmeta';
	$wp_customize->add_control(
		new bgbn_Customize_Misc_Control(
			$wp_customize,
			$control_prefix . $setting_id,
			array(
				'section'  => $section,
				'type'     => 'heading',
				'label'    => __( 'Post Meta', 'bgbn' ),
				'priority' => $priority->add()
			)
		)
	);

	// Show categories
	$setting_id = $setting_prefix . '-show-categories';
	$wp_customize->add_setting(
		$setting_id,
		array(
			'default'           => bgbn_get_default( $setting_id ),
			'type'              => 'theme_mod',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		$control_prefix . $setting_id,
		array(
			'settings' => $setting_id,
			'section'  => $section,
			'label'    => __( 'Show categories', 'bgbn' ),
			'type'     => 'checkbox',
			'priority' => $priority->add()
		)
	);

	// Show tags
	$setting_id = $setting_prefix . '-show-tags';
	$wp_customize->add_setting(
		$setting_id,
		array(
			'default'           => bgbn_get_default( $setting_id ),
			'type'              => 'theme_mod',
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		$control_prefix . $setting_id,
		array(
			'settings' => $setting_id,
			'section'  => $section,
			'label'    => __( 'Show tags', 'bgbn' ),
			'type'     => 'checkbox',
			'priority' => $priority->add()
		)
	);
}
endif;